@@ -29,10 +29,12 @@ typedef struct _FmAppLaunchContext {
 G_DEFINE_TYPE(FmAppLaunchContext, fm_app_launch_context, G_TYPE_APP_LAUNCH_CONTEXT)
 
 static char* fm_app_launch_context_get_display(GAppLaunchContext * /*context*/, GAppInfo * /*info*/, GList * /*files*/) {
-  Display* dpy = QX11Info::display();
-  if(dpy) {
-    char* xstr = DisplayString(dpy);
-    return g_strdup(xstr);
+  if(QX11Info::isPlatformX11()) {
+    Display* dpy = QX11Info::display();
+    if(dpy) {
+        char* xstr = DisplayString(dpy);
+        return g_strdup(xstr);
+    }
   }
   return nullptr;
 }
