@@ -187,6 +187,9 @@ void FolderModel::updateCutFilesSet() {
     bool cutPathFound = false;
     const QClipboard* clipboard = QApplication::clipboard();
     const QMimeData* data = clipboard->mimeData();
+    if(data == nullptr) {
+        return; // possible under Wayland
+    }
 
     // Gnome, LXDE, XFCE (see utilities.cpp -> pasteFilesFromClipboard)
     if(data->hasFormat(QStringLiteral("x-special/gnome-copied-files"))) {
@@ -588,7 +591,8 @@ bool FolderModel::dropMimeData(const QMimeData* data, Qt::DropAction action, int
         srcPaths = Fm::pathListFromQUrls(data->urls());
     }
 
-    // FIXME: should we put this in dropEvent handler of FolderView instead?
+    // NOTE: If the DND is done with no key modifier, the current method will not be called.
+    // Instead, the dropEvent handler of FolderView will do the job after asking the user.
     if(!srcPaths.empty()) {
         //qDebug("drop action: %d", action);
         switch(action) {
